@@ -189,11 +189,13 @@ class EnderecoLog(models.Model):
     cep_form = models.CharField(max_length=15, null=True)
     municipio = models.ForeignKey('core.Municipio', on_delete=models.DO_NOTHING, null=True)
     bairro_cep = models.CharField(max_length=100, null=True)
-    rua_cep = models.CharField(max_length=100, null=True)
+    endereco_cep = models.CharField(max_length=100, null=True)
+    endereco_comp_cep = models.CharField(max_length=200, null=True)
     latitude_cep = models.CharField(max_length=200, null=True)
     longitude_cep = models.CharField(max_length=200, null=True)
     tipo_cep = models.CharField(max_length=200, null=True)
 
+
     class Meta(Log.Meta):
         abstract = True
 
@@ -203,7 +205,7 @@ class EnderecoComplementoLog(models.Model):
     numero = models.CharField(max_length=30, null=True)
     complemento = models.CharField(max_length=100, null=True)
     bairro = models.CharField(max_length=100, null=True)
-    rua = models.CharField(max_length=100, null=True)
+    endereco = models.CharField(max_length=100, null=True)
 
     ponto_referencia = models.CharField(max_length=100, null=True)
     latitude = models.CharField(max_length=200, null=True)
