@@ -246,7 +246,8 @@ class TipoDesconto(core.models.Log):
 
 class Desconto(core.models.Log):
     tipo = models.ForeignKey('produto.TipoDesconto', on_delete=models.DO_NOTHING, null=True)
-    qtd_desc = models.IntegerField(null=True)
+    qtd_ini_desc = models.IntegerField(null=True)
+    qtd_fim_desc = models.IntegerField(null=True)
     valor_desc = models.DecimalField(max_digits=14, decimal_places=2, null=True)
     per_desc = models.DecimalField(max_digits=10, decimal_places=2, null=True)
     dat_ini = models.DateField(null=True)
